
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '1.11.0'
version = '1.11.0'
full_version = '1.11.0'
git_revision = '49b3978d59cc9b45cc2e955bc8f53305100995d9'
release = True

if not release:
    version = full_version
